pub struct FormatVolumeOptionsBuilder { /* private fields */ }Expand description
Builder for FormatVolumeOptions.
Implementations
Sourceimpl FormatVolumeOptionsBuilder
impl FormatVolumeOptionsBuilder
Sourcepub fn pack_bitmap(&mut self, value: bool) -> &mut Self
pub fn pack_bitmap(&mut self, value: bool) -> &mut Self
Whether or not to pack the bitmap right after the FAT for better performance and space
usage. Defaults to true.
Sourcepub fn full_format(&mut self, value: bool) -> &mut Self
pub fn full_format(&mut self, value: bool) -> &mut Self
Whether to fully format the volume, which takes longer. Defaults to false.
Sourcepub fn partition_offset(&mut self, value: u64) -> &mut Self
pub fn partition_offset(&mut self, value: u64) -> &mut Self
Media-relative sector offset of the partition which hosts the given exFAT volume. Defaults
to 0.
Sourcepub fn bytes_per_sector(&mut self, value: u16) -> &mut Self
pub fn bytes_per_sector(&mut self, value: u16) -> &mut Self
Amount of bytes per sector. Must be a power of 2 and between 512 and 4096.
Sourcepub fn boundary_align(&mut self, value: u32) -> &mut Self
pub fn boundary_align(&mut self, value: u32) -> &mut Self
Byte alignment for filesystem structures like the FAT and Up-case table. Defaults to
DEFAULT_BOUNDARY_ALIGNEMENT.
Sourcepub fn build(
&self,
) -> Result<FormatVolumeOptions, FormatVolumeOptionsBuilderError>
pub fn build( &self, ) -> Result<FormatVolumeOptions, FormatVolumeOptionsBuilderError>